@@ -15,6 +15,7 @@ from typing import Any, Dict, List, Optional, Set, Union
 
 import numpy as np
 import pandas as pd
+import pyarrow
 
 try:
     # pylint: disable=unused-import
@@ -29,6 +30,8 @@ except ImportError:
 
 from ecl2df import __version__
 
+from .constants import MAGIC_STDOUT
+
 # Parse named JSON files, this exposes a dict of dictionary describing the contents
 # of supported Eclipse keyword data
 OPMKEYWORDS: Dict[str, dict] = {}
@@ -79,15 +82,13 @@ for keyw in [
         (Path(__file__).parent / "opmkeywords" / keyw).read_text()
     )
 
-# This is a magic filename that means read/write from/to stdout
-# This makes it impossible to write to a file called "-" on disk
-# but that would anyway create a lot of other problems in the shell.
-MAGIC_STDOUT: str = "-"
 
 SVG_COLOR_NAMES = [
     color.lower()
     for color in (
-        (Path(__file__).parent / "svg_color_keyword_names.txt").read_text().splitlines()
+        (Path(__file__).parent / "svg_color_keyword_names.txt")
+        .read_text(encoding="utf-8")
+        .splitlines()
     )
 ]
 
@@ -95,7 +96,7 @@ logger: logging.Logger = logging.getLogger(__name__)
 
 
 def write_dframe_stdout_file(
-    dframe: pd.DataFrame,
+    dframe: Union[pd.DataFrame, pyarrow.Table],
     output: str,
     index: bool = False,
     caller_logger: Optional[logging.Logger] = None,
@@ -116,15 +117,21 @@ def write_dframe_stdout_file(
     if output == MAGIC_STDOUT:
         # Ignore pipe errors when writing to stdout:
         signal.signal(signal.SIGPIPE, signal.SIG_DFL)
-        dframe.to_csv(sys.stdout, index=index)
+        if isinstance(dframe, pd.DataFrame):
+            dframe.to_csv(sys.stdout, index=index)
+        else:
+            raise SystemExit("Not possible to write arrow format to stdout")
     else:
-        if caller_logger and dframe.empty:
+        if caller_logger and isinstance(dframe, pd.DataFrame) and dframe.empty:
             caller_logger.warning("Empty dataframe being written to disk")
         if caller_logger and not logstr:
             caller_logger.info("Writing to file %s", str(output))
         elif caller_logger and logstr:
             caller_logger.info(logstr)
-        dframe.to_csv(output, index=index)
+        if isinstance(dframe, pd.DataFrame):
+            dframe.to_csv(output, index=index)
+        else:
+            pyarrow.feather.write_feather(dframe, dest=output)
 
 
 def write_inc_stdout_file(string: str, outputfilename: str) -> None:
@@ -135,7 +142,7 @@ def write_inc_stdout_file(string: str, outputfilename: str) -> None:
         signal.signal(signal.SIGPIPE, signal.SIG_DFL)
         print(string)
     else:
-        Path(outputfilename).write_text(string)
+        Path(outputfilename).write_text(string, encoding="utf-8")
         print(f"Wrote to {outputfilename}")
 
 
@@ -731,7 +738,7 @@ def parse_lyrfile(filename: str) -> Optional[List[Dict[str, Any]]]:
 
     """  # noqa
 
-    zonelines = Path(filename).read_text().splitlines()
+    zonelines = Path(filename).read_text(encoding="utf-8").splitlines()
 
     # Remove comments, support both "--" and "#":
     zonelines = [line.split("--")[0].strip() for line in zonelines]
@@ -812,7 +819,7 @@ def get_wells_matching_template(template: str, wells: list):
             "Well template not allowed to start with a wildcard character: "
             f"Must be preceded with a \\: {template}"
         )
-    elif template.startswith("\\"):
+    if template.startswith("\\"):
         # Note that the two \\ are actually read as one and
         # this will return True for f.ex '\*P1'
         template = template[1:]
