@@ -20,9 +20,11 @@ from typing import Dict, List, Optional, Tuple, Type, Union
 import dateutil.parser
 import numpy as np
 import pandas as pd
+import pyarrow
+import pyarrow.feather
 from ecl.eclfile import EclFile
 
-from ecl2df import __version__, common
+from ecl2df import __version__, common, getLogger_ecl2csv
 
 from .eclfiles import EclFiles
 
@@ -115,6 +117,29 @@ def dates2rstindices(
     return (rstindices, chosendates, isostrings)
 
 
+def _df2pyarrow(dframe: pd.DataFrame) -> pyarrow.Table:
+    """Construct a pyarrow table from dataframe with
+    grid information
+
+    The index in the dataframe will be ignored
+
+    32-bit types will be used for integers and floats (todo)
+    """
+    field_list: List[pyarrow.Field] = []
+    for colname in dframe.columns:
+        if pd.api.types.is_integer_dtype(dframe.dtypes[colname]):
+            dtype = pyarrow.int32()
+        elif pd.api.types.is_string_dtype(dframe.dtypes[colname]):
+            # Parameters are potentially merged into the dataframe.
+            dtype = pyarrow.string()
+        else:
+            dtype = pyarrow.float32()
+        field_list.append(pyarrow.field(colname, dtype))
+
+    schema = pyarrow.schema(field_list)
+    return pyarrow.Table.from_pandas(dframe, schema=schema, preserve_index=False)
+
+
 def rst2df(
     eclfiles: EclFiles,
     date: Union[str, datetime.date, List[datetime.date]],
@@ -551,6 +576,7 @@ def fill_parser(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
         help="Drop constant columns from the dataset",
     )
     parser.add_argument("-v", "--verbose", action="store_true", help="Be verbose")
+    parser.add_argument("--arrow", action="store_true", help="Write to pyarrow format")
     return parser
 
 
@@ -637,7 +663,7 @@ def df2ecl(
         elif dtype.startswith("float"):
             dtype = float
         else:
-            raise ValueError("Wrong dtype argument {}".format(dtype))
+            raise ValueError(f"Wrong dtype argument {dtype}")
 
     # Figure out the total number of cells for which we need to export data for:
     global_size = None
@@ -689,7 +715,7 @@ def df2ecl(
 
     for keyword in keywords:
         if keyword not in grid_df.columns:
-            raise ValueError("Keyword {} not found in grid dataframe".format(keyword))
+            raise ValueError(f"Keyword {keyword} not found in grid dataframe")
         vector = np.zeros(global_size)
         vector[grid_df["GLOBAL_INDEX"].astype(int).values] = grid_df[keyword]
         if dtype == int:
@@ -718,8 +744,9 @@ def df2ecl(
         )
         string += "\n/"
         if not nocomments:
-            string += " -- {}: {} active cells, {} total cell count\n".format(
-                keyword, active_cells, global_size
+            string += (
+                f" -- {keyword}: {active_cells} active cells, "
+                f"{global_size} total cell count\n"
             )
         string += "\n"
 
@@ -731,8 +758,9 @@ def df2ecl(
 
 def grid_main(args) -> None:
     """This is the command line API"""
-    if args.verbose:
-        logging.basicConfig(level=logging.INFO)
+    logger = getLogger_ecl2csv(  # pylint: disable=redefined-outer-name
+        __name__, vars(args)
+    )
     eclfiles = EclFiles(args.DATAFILE)
     grid_df = df(
         eclfiles,
@@ -741,6 +769,8 @@ def grid_main(args) -> None:
         dropconstants=args.dropconstants,
         stackdates=args.stackdates,
     )
+    if args.arrow:
+        grid_df = _df2pyarrow(grid_df)
     common.write_dframe_stdout_file(
         grid_df, args.output, index=False, caller_logger=logger
     )
