@@ -1,5 +1,6 @@
 """Test module for nnc2df"""
 
+import os
 from pathlib import Path
 
 import numpy as np
@@ -9,13 +10,40 @@ import pytest
 from ecl2df import ecl2csv, gruptree
 from ecl2df.eclfiles import EclFiles
 
+try:
+    import opm  # noqa
+except ImportError:
+    pytest.skip(
+        "OPM is not installed, nothing relevant in here then",
+        allow_module_level=True,
+    )
+
 TESTDIR = Path(__file__).absolute().parent
-DATAFILE = str(TESTDIR / "data/reek/eclipse/model/2_R001_REEK-0.DATA")
+REEK = str(TESTDIR / "data/reek/eclipse/model/2_R001_REEK-0.DATA")
+# EIGTHCELLS is to be used in test_main_subparser when #356 is solved:
+EIGHTCELLS = str(TESTDIR / "data/eightcells/EIGHTCELLS.DATA")
+
+
+def test_eightcells_dataset():
+    """Test Eightcells dataset"""
+    eclfiles = EclFiles(EIGHTCELLS)
+    gruptree_df = gruptree.df(eclfiles.get_ecldeck())
+
+    expected_dframe = pd.DataFrame(
+        [
+            ["2000-01-01", "FIELD", "GRUPTREE", np.nan],
+            ["2000-01-01", "OP1", "WELSPECS", "OPS"],
+            ["2000-01-01", "OPS", "GRUPTREE", "FIELD"],
+        ],
+        columns=["DATE", "CHILD", "KEYWORD", "PARENT"],
+    )
+    expected_dframe["DATE"] = pd.to_datetime(expected_dframe["DATE"])
+    pd.testing.assert_frame_equal(gruptree_df, expected_dframe, check_dtype=False)
 
 
 def test_gruptree2df():
     """Test that dataframes are produced"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(REEK)
     grupdf = gruptree.df(eclfiles.get_ecldeck())
 
     assert not grupdf.empty
@@ -58,9 +86,9 @@ WELSPECS
     assert len(withstart) == 6
 
 
-def test_grupnet_rst_docs(tmpdir):
+def test_grupnet_rst_docs(tmp_path):
     """Provide the input and output for the examples in the RST documentation"""
-    tmpdir.chdir()
+    os.chdir(tmp_path)
     schstr = """
 START
  01 'JAN' 2000 /
@@ -335,6 +363,51 @@ def test_multiple_roots():
         gruptree.tree_from_dict({"foo": 1, "bar": 2})
 
 
+@pytest.mark.parametrize(
+    "dframe, expected",
+    [
+        (pd.DataFrame(), [{}]),
+        pytest.param(
+            pd.DataFrame([{"FOO": "BAR"}]),
+            [{}],
+            marks=pytest.mark.xfail(raises=KeyError),
+            # "PARENT" is required.
+        ),
+        pytest.param(
+            pd.DataFrame([{"PARENT": "A"}]),
+            [{}],
+            marks=pytest.mark.xfail(raises=KeyError)
+            # "CHILD" is also required
+        ),
+        (pd.DataFrame([{"PARENT": "A", "CHILD": "B"}]), [{"A": {"B": {}}}]),
+        (
+            pd.DataFrame(
+                [{"PARENT": "A", "CHILD": "B"}, {"PARENT": "B", "CHILD": "C"}]
+            ),
+            [{"A": {"B": {"C": {}}}}],
+        ),
+        (
+            # DATE is not used
+            pd.DataFrame([{"PARENT": "A", "CHILD": "B", "DATE": "2000-01-01"}]),
+            [{"A": {"B": {}}}],
+        ),
+        pytest.param(
+            # DATE is not used, but will be checked that it is the same:
+            pd.DataFrame(
+                [
+                    {"PARENT": "A", "CHILD": "B", "DATE": "2000-01-01"},
+                    {"PARENT": "A", "CHILD": "B", "DATE": "2040-01-01"},
+                ]
+            ),
+            None,
+            marks=pytest.mark.xfail(raises=ValueError),
+        ),
+    ],
+)
+def test_edge_dataframe2dict(dframe, expected):
+    assert gruptree.edge_dataframe2dict(dframe) == expected
+
+
 def test_emptytree_strdeck():
     """Test empty schedule sections. Don't want to crash"""
     schstr = ""
@@ -350,14 +423,22 @@ def test_emptytree_strdeck():
     assert treelibtree == ""
 
 
-def test_emptytree_commandlinetool(tmpdir, mocker, caplog):
-    tmpdir.chdir()
+def test_emptytree_commandlinetool(tmp_path, mocker, caplog):
+    os.chdir(tmp_path)
     Path("EMPTY.DATA").write_text("")
     mocker.patch("sys.argv", ["ecl2csv", "gruptree", "--prettyprint", "EMPTY.DATA"])
     ecl2csv.main()
     assert "No tree data to prettyprint" in caplog.text
 
 
+def test_cli_nothing_to_do(mocker, capsys):
+    """Test that the client says nothing to do when DATA is supplied, but no action."""
+    mocker.patch("sys.argv", ["ecl2csv", "gruptree", "EMPTY.DATA"])
+    with pytest.raises(SystemExit):
+        ecl2csv.main()
+    assert "Nothing to do" in capsys.readouterr().out
+
+
 def test_tstep():
     """Test that we can parse a deck using TSTEP for timestepping"""
     schstr = """
@@ -382,10 +463,10 @@ WELSPECS
     print(grupdf)
 
 
-def test_main(tmpdir, mocker):
+def test_main(tmp_path, mocker):
     """Test command line interface"""
-    tmpcsvfile = tmpdir.join("gruptree.csv")
-    mocker.patch("sys.argv", ["ecl2csv", "gruptree", DATAFILE, "-o", str(tmpcsvfile)])
+    tmpcsvfile = tmp_path / "gruptree.csv"
+    mocker.patch("sys.argv", ["ecl2csv", "gruptree", REEK, "-o", str(tmpcsvfile)])
     ecl2csv.main()
 
     assert Path(tmpcsvfile).is_file()
@@ -395,7 +476,7 @@ def test_main(tmpdir, mocker):
 
 def test_prettyprint_commandline(mocker, capsys):
     """Test pretty printing via command line interface"""
-    mocker.patch("sys.argv", ["ecl2csv", "gruptree", DATAFILE, "--prettyprint"])
+    mocker.patch("sys.argv", ["ecl2csv", "gruptree", REEK, "--prettyprint"])
     ecl2csv.main()
     stdout = capsys.readouterr().out.strip()
     print(stdout)
@@ -463,12 +544,10 @@ FIELD
     )
 
 
-def test_main_subparser(tmpdir, mocker):
+def test_main_subparser(tmp_path, mocker):
     """Test command line interface"""
-    tmpcsvfile = tmpdir.join("gruptree.csv")
-    mocker.patch(
-        "sys.argv", ["ecl2csv", "gruptree", "-v", DATAFILE, "-o", str(tmpcsvfile)]
-    )
+    tmpcsvfile = tmp_path / "gruptree.csv"
+    mocker.patch("sys.argv", ["ecl2csv", "gruptree", "-v", REEK, "-o", str(tmpcsvfile)])
     ecl2csv.main()
 
     assert Path(tmpcsvfile).is_file()
@@ -611,14 +690,16 @@ NODEPROP
 /
         """,
             # TMPL_B is not in any trees. The WELSPECS line is added
-            # only when there is a new GRUPTREE tree
+            # only when there is a new GRUPTREE tree and a GRUPTREE
+            # entry is added connecting TMPL_B to the FIELD node.
             # TMPL_A is in both trees, but is not repeated at the date
-            # where there is two trees
+            # where there are two trees
             pd.DataFrame(
                 [
                     ["2000-01-01", "FIELD", "GRUPTREE", np.nan],
                     ["2000-01-01", "TMPL_A", "GRUPTREE", "FIELD"],
                     ["2000-01-01", "WELL_2", "WELSPECS", "TMPL_B"],
+                    ["2000-01-01", "TMPL_B", "GRUPTREE", "FIELD"],
                     ["2000-01-01", "FIELD", "BRANPROP", np.nan],
                     ["2000-01-01", "NODE_A", "BRANPROP", "FIELD"],
                     ["2000-01-01", "TMPL_A", "BRANPROP", "NODE_A"],
@@ -649,7 +730,7 @@ def test_branprop_nodeprop(schstr, expected_dframe, check_columns):
     )
 
 
-def test_prettyprint(tmpdir, mocker, caplog):
+def test_prettyprint(tmp_path, mocker, caplog):
     """ "Test prettyprinting with multiple dates and both
     GRUPTREE and BRANPROP trees"""
     schstr = """
@@ -683,11 +764,10 @@ NODEPROP
 Date: 2000-01-01
 GRUPTREE trees:
 FIELD
-└── TMPL_A
-    └── WELL_1
-
-TMPL_B
-└── WELL_2
+├── TMPL_A
+│   └── WELL_1
+└── TMPL_B
+    └── WELL_2
 
 BRANPROP trees:
 FIELD
